.. rename title [CHANGE THIS]:

.. _home:

Babilonia
############################################

Welcome to ``babilonia`` documentation!

Handle accounting and finances in Brazil using Python.

Contents
********************************************

.. list all pages it must contain in the home page [CHANGE THIS]:

.. toctree::
   :maxdepth: 1

   Home <self>
   about
   usage
   api
   development
